@@ -25,21 +25,16 @@ from google.auth import credentials as ga_credentials  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
-import pkg_resources
 
+from google.cloud.contact_center_insights_v1 import gapic_version as package_version
 from google.cloud.contact_center_insights_v1.types import (
     contact_center_insights,
     resources,
 )
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-contact-center-insights",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class ContactCenterInsightsTransport(abc.ABC):
@@ -53,7 +48,7 @@ class ContactCenterInsightsTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -177,6 +172,16 @@ class ContactCenterInsightsTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.bulk_analyze_conversations: gapic_v1.method.wrap_method(
+                self.bulk_analyze_conversations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.ingest_conversations: gapic_v1.method.wrap_method(
+                self.ingest_conversations,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.export_insights_data: gapic_v1.method.wrap_method(
                 self.export_insights_data,
                 default_timeout=None,
@@ -232,6 +237,11 @@ class ContactCenterInsightsTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.delete_issue: gapic_v1.method.wrap_method(
+                self.delete_issue,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.calculate_issue_model_stats: gapic_v1.method.wrap_method(
                 self.calculate_issue_model_stats,
                 default_timeout=None,
@@ -405,6 +415,24 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def bulk_analyze_conversations(
+        self,
+    ) -> Callable[
+        [contact_center_insights.BulkAnalyzeConversationsRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def ingest_conversations(
+        self,
+    ) -> Callable[
+        [contact_center_insights.IngestConversationsRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def export_insights_data(
         self,
@@ -510,6 +538,15 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def delete_issue(
+        self,
+    ) -> Callable[
+        [contact_center_insights.DeleteIssueRequest],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def calculate_issue_model_stats(
         self,
